@@ -24,6 +24,7 @@ import shutil
 import subprocess
 import sys
 import typing
+from collections import OrderedDict
 from functools import wraps
 from typing import Dict
 from typing import Optional
@@ -31,7 +32,7 @@ from typing import Set
 from typing import Tuple
 
 import yaml
-import click
+import rich_click as click
 from rich.console import Console
 from rich.text import Text
 from rich.table import Table
@@ -47,6 +48,7 @@ from thamos.exceptions import NoRuntimeEnvironmentError
 from thamos.exceptions import RequirementsFileError
 from thamos.config import config as configuration
 from thamos.lib import advise_here as thoth_advise_here
+from thamos.lib import get_diff
 from thamos.lib import add_requirements_to_project
 from thamos.lib import collect_support_information_dict
 from thamos.lib import check_runtime_environment_run
@@ -62,16 +64,19 @@ from thamos.lib import load_dot_env
 from thamos.lib import load_files
 from thamos.lib import provenance_check as thoth_provenance_check
 from thamos.lib import print_dependency_graph
+from thamos.lib import print_advise_results
 from thamos.lib import get_verified_packages_from_static_analysis
 from thamos.lib import write_configuration
 from thamos.lib import write_files
 from thamos.utils import workdir
+from thamos.cli_config import init_rich_click
 from thamos import __version__ as thamos_version
 
 # Suppress anoying errors when name not known (disable_warnings() does not work here).
 logging.getLogger("urllib3.connectionpool").setLevel(logging.ERROR)
 daiquiri.setup(level=logging.INFO)
 _LOGGER = logging.getLogger("thamos")
+init_rich_click()
 
 _EMOJI = {
     "WARNING": Text("\u26a0\ufe0f WARNING", style="yellow"),
@@ -81,6 +86,11 @@ _EMOJI = {
     "CVE": Text("\u2620\uFE0F  CVE \u2620\uFE0F", "red"),
 }
 
+_DIFFERENCE = {
+    "REMOVED": Text("REMOVED", style="bold red"),
+    "ADDED": Text("ADDED", "green"),
+}
+
 # Align of columns in table - default is left, values stated here are adjusted otherwise.
 _TABLE_COLS_ALIGN = {
     "type": "c",
@@ -127,6 +137,49 @@ _REPORT_TRANSLATION_TABLE_ENVIRONMENTS = {
     "python_version": "Python version",
 }
 
+_REPORT_TRANSLATION_TABLE_SCORECARD_TAGS = {
+    "binary-artifacts": "projects have binary artifacts in the source repository",
+    "no-binary-artifacts": "projects do NOT have binary artifacts in the source repository",
+    "unfixed-vulnerabilities": "projects have open or unfixed vulnerabilities on the OSV service",
+    "no-unfixed-vulnerabilities": "projects do NOT have open or unfixed vulnerabilities on the OSV service",
+    "code-review": "projects require code review before the code is merged",
+    "no-code-review": "projects do NOT require code review before the code is merged",
+    "actively-maintained": "projects are actively maintained",
+    "no-actively-maintained": "projects are NOT actively maintained",
+    "automatic-updates": "projects use use tools for automatic dependency updates",
+    "no-automatic-updates": "projects do NOT use use tools for automatic dependency updates",
+    "branch-protection": "projects have branch protection setup",
+    "no-branch-protection": "projects do NOT have branch protection setup",
+    "least-privileged-workflow": "projects follow the principle of least privileged in GitHub workflows",
+    "no-least-privileged-workflow": "projects do NOT follow the principle of least privileged in GitHub workflows",
+    "security-policy": "projects have a security policy published",
+    "no-security-policy": "projects do NOT have a security policy published",
+    "signed-releases": "projects cryptographically sign released artifacts",
+    "no-signed-releases": "projects do NOT cryptographically sign released artifacts",
+    "fuzzing": "projects use fuzzing",
+    "no-fuzzing": "projects do NOT use fuzzing",
+    "published-package": "projects are published as packages",
+    "no-published-package": "projects are NOT published as packages",
+    "cii": "projects follow best CII practices",
+    "no-cii": "projects do NOT follow best CII practices",
+    "pinned-dependencies": "projects use pinned dependencies",
+    "no-pinned-dependencies": "projects do NOT use pinned dependencies",
+    "multiple-companies-contributors": "projects have a set of contributors from multiple companies",
+    "no-multiple-companies-contributors": "projects do NOT have a set of contributors from multiple companies",
+    "ci-tests": "projects run CI tests before pull requests are merged",
+    "no-ci-tests": "projects do NOT run CI tests before pull requests are merged",
+    "static-analysis": "projects use static source code analysis",
+    "no-static-analysis": "projects do NOT use static source code analysis",
+    "dangerous-patterns": "projects GitHub Action workflows have dangerous code patterns",
+    "no-dangerous-patterns": "projects GitHub Action workflows do NOT have dangerous code patterns",
+    "license": "projects have published a license",
+    "no-license": "projects have NOT published a license",
+    "webhook-token": "projects have a token for webhooks configured in their"
+    " repository to authenticate the origins of requests",
+    "no-webhook-token": "projects do NOT have a token for webhooks configured in their"
+    " repository to authenticate the origins of requests",
+}
+
 
 def handle_cli_exception(func: typing.Callable) -> typing.Callable:
     """Suppress exception in CLI if debug mode was not turned on."""
@@ -193,6 +246,9 @@ def _print_report(
             ):
                 entry = _EMOJI.get(entry, entry)
 
+            if isinstance(entry, str) and entry in _DIFFERENCE:
+                entry = _DIFFERENCE.get(entry, entry)
+
             if isinstance(entry, list):
                 entry = ", ".join(entry)
 
@@ -206,13 +262,47 @@ def _print_report(
     console.print(table, justify="center")
 
 
+def _print_report_summary(analysis_id: str, report: list, *, json_output: bool = False):
+    """Print reasoning to user."""
+    types = {"INFO": 0, "WARNING": 0, "ERROR": 0}
+    for item in report:
+        types[item["type"]] += 1
+
+    if json_output:
+        click.echo(
+            json.dumps(
+                {
+                    "count": types,
+                    "thoth_search_url": f"https://thoth-station.ninja/search/advise/{analysis_id}",
+                },
+                sort_keys=True,
+                indent=2,
+            )
+        )
+        return
+
+    console = Console()
+
+    console.print("Short Summary", justify="center", style="bold")
+    console.print(
+        f"The advise analysis fished with {types['INFO']} INFO messages, {types['WARNING']} WARNING messages,"
+        + f" and {types['ERROR']} ERROR messages.",
+        justify="center",
+    )
+    console.print(
+        "Results can be browsed in Thoth search: [link https://thoth-station.ninja/search/advise/"
+        + f"{analysis_id}]https://thoth-station.ninja/search/advise/{analysis_id}",
+        justify="center",
+    )
+
+
 def _parse_labels(label: Optional[str]) -> Optional[Dict[str, str]]:
     """Parse labels from their string representation."""
     if not label:
         return None
 
     labels: Dict[str, str] = {}
-    parts = label.split(",")
+    parts = label.split(";")
     for part in parts:
         lab = part.split("=")
         if len(lab) != 2:
@@ -232,7 +322,88 @@ def _parse_labels(label: Optional[str]) -> Optional[Dict[str, str]]:
     return labels
 
 
-class AliasedGroup(click.Group):
+def _print_advise_justifications(
+    result,
+    json_output: bool = False,
+):
+    if result["report"] and result["report"]["stack_info"]:
+        _print_report(
+            result["report"]["stack_info"],
+            json_output=json_output,
+            title="Application stack guidance",
+        )
+
+    # Print report of the best one - thus index zero.
+    if result["report"] and result["report"]["products"]:
+        if result["report"]["products"][0]["justification"]:
+            _print_report(
+                result["report"]["products"][0]["justification"],
+                json_output=json_output,
+                title="Recommended stack report",
+            )
+        else:
+            click.echo("No justification was made for the recommended stack")
+
+    return None
+
+
+def _compute_metrics_scorecards(report) -> Optional[OrderedDict]:
+    """Aggregate OSSF Scorecards information from report and compute metrics."""
+    nb_dependencies = 0
+    scorecards_metrics = {}
+
+    if report["products"] and report["products"][0]["dependency_graph"]["nodes"]:
+        nb_dependencies = len(report["products"][0]["dependency_graph"]["nodes"])
+
+    for justification in report["products"][0]["justification"]:
+        if "scorecard" in justification["link"]:
+            if "tag" in justification:
+                message = _REPORT_TRANSLATION_TABLE_SCORECARD_TAGS[justification["tag"]]
+
+            # TO DO: Remove when corresponding prescriptions have been updated with tags
+            else:
+                replacement_words = {
+                    "Project ": "projects ",
+                    " is ": " are ",
+                    " does ": " do ",
+                    " has ": " have ",
+                    " runs ": " run ",
+                    " requires ": " require ",
+                    " uses ": " use ",
+                    " follows ": " follow ",
+                    " signs ": " sign ",
+                    " NOT ": " not ",
+                }
+                message = justification["message"].strip()
+
+                for k, v in replacement_words.items():
+                    message = message.replace(k, v)
+
+            message = message.split("based")[0]
+
+            if message not in scorecards_metrics:
+                scorecards_metrics[message] = 1
+
+            else:
+                scorecards_metrics[message] += 1
+
+    if scorecards_metrics != {}:
+
+        # TO DO: find a better sorting logic based on tags
+        return OrderedDict(
+            sorted(
+                {
+                    k: int(v * nb_dependencies / 100)
+                    for k, v in scorecards_metrics.items()
+                }.items(),
+                key=lambda t: "not" in t[0],
+            )
+        )
+
+    return None
+
+
+class AliasedGroup(click.RichGroup):
     """Provide clever command aliases."""
 
     def get_command(self, ctx, cmd_name):
@@ -378,13 +549,15 @@ def install(
     This command assumes requirements files are present and dependencies are already resolved.
     If that's not the case, issue `thamos advise` before running this command.
 
-    Examples:
+    [bold yellow]Examples:[/bold yellow]
+    [purple]
 
-      thamos install --runtime-environment "testing"
+      thamos install --runtime-environment testing
 
       thamos install --dev
 
       thamos install --no-dev -- --force-reinstall
+    [/purple]
     """
     try:
         thamos_install(
@@ -440,13 +613,15 @@ def run(
 ) -> None:  # noqa: D412
     """Run the command in virtual environment.
 
-    Examples:
+    [bold yellow]Examples:[/bold yellow]
+    [purple]
 
       thamos run ./app.py
 
-      thamos run --runtime-environment "stage" -- flask --help
+      thamos run --runtime-environment stage -- flask --help
 
-      thamos run --runtime-environment "testing" --no-pedantic -- train.py
+      thamos run --runtime-environment testing --no-pedantic -- ./train.py
+    [/purple]
     """
     virtualenv_path = configuration.get_virtualenv_path(runtime_environment)
     if virtualenv_path is None:
@@ -518,6 +693,8 @@ def venv(ctx, runtime_environment: Optional[str] = None) -> None:
     else:
         _error_virtual_environment(virtualenv_path)
 
+    click.echo(virtualenv_path)
+
 
 @cli.command("purge")
 @click.pass_context
@@ -542,13 +719,15 @@ def purge(
 ) -> None:  # noqa: D412
     """Remove virtual environment created.
 
-    Examples:
+    [bold yellow]Examples:[/bold yellow]
+    [purple]
 
       thamos purge
 
-      thamos purge --runtime-environment "testing"
+      thamos purge --runtime-environment testing
 
       thamos purge --all
+    [/purple]
     """
     if all:
         for runtime_environment_config in configuration.list_runtime_environments():
@@ -628,6 +807,16 @@ def purge(
 @click.option(
     "--json", "-j", "json_output", is_flag=True, help="Print output in JSON format."
 )
+@click.option(
+    "--short",
+    is_flag=True,
+    help="Shorten the analysis output.",
+)
+@click.option(
+    "--diff",
+    is_flag=True,
+    help="Return only the difference between the current analysis output and the last run analysis.",
+)
 @click.option(
     "--force",
     is_flag=True,
@@ -674,11 +863,20 @@ def purge(
     "-l",
     envvar="THAMOS_LABELS",
     type=str,
-    metavar="KEY1=VALUE1,KEY2=VALUE2",
+    metavar="KEY1=VALUE1;KEY2=VALUE2,VALUE3",
     default=None,
     show_default=True,
     help="Labels used to label the request.",
 )
+@click.option(
+    "--scoring",
+    envvar="THAMOS_SHOW_METRICS",
+    type=str,
+    is_flag=True,
+    default=False,
+    show_default=True,
+    help="Experimental feature: show Thoth package scoring based on OSSF Security Scorecards",
+)
 @handle_cli_exception
 def advise(
     debug: bool = False,
@@ -688,11 +886,14 @@ def advise(
     no_wait: bool = False,
     no_static_analysis: bool = False,
     json_output: bool = False,
+    short: bool = False,
+    diff: bool = False,
     force: bool = False,
     dev: bool = False,
     no_user_stack: bool = False,
     install: bool = False,
     labels: Optional[str] = None,
+    scoring: bool = False,
     write_advised_manifest_changes: Optional[str] = None,
 ) -> None:  # noqa: D412
     """Ask Thoth for recommendations on the application stack.
@@ -702,15 +903,17 @@ def advise(
     static source code analysis and requirements for the application and sends them to the
     remote service. Optionally, install packages resolved by Thoth.
 
-    Examples:
+    [bold yellow]Examples:[/bold yellow]
+    [purple]
 
-      thamos advise --runtime-environment "testing" --labels foo=bar,qux=baz
+      thamos advise --runtime-environment testing --labels 'foo=bar;qux=baz,bap'
 
       thamos advise --dev
 
       thamos advise --install
 
       thamos advise --no-static-analysis --no-user-stack
+    [/purple]
     """
     if install and no_wait:
         _LOGGER.error("Cannot install dependencies as --no-wait was provided")
@@ -727,6 +930,11 @@ def advise(
             jl("no_dev"),
         )
 
+    try:
+        last_analysis_id = get_last_analysis_id()
+    except FileNotFoundError:
+        last_analysis_id = None
+
     # In CLI we always call to obtain only the best software stack (count is implicitly set to 1).
     results = thoth_advise_here(
         recommendation_type=recommendation_type,
@@ -751,7 +959,7 @@ def advise(
         click.echo(results)
         sys.exit(0)
 
-    result, error = results
+    result, error, metadata = results
     if error:
         if json_output:
             json.dump(result, sys.stdout, indent=2)
@@ -774,23 +982,40 @@ def advise(
         sys.exit(4)
     if not no_write:
         with cwd(configuration.get_overlays_directory(runtime_environment)):
-            if result["report"] and result["report"]["stack_info"]:
-                _print_report(
+            if short:
+                _print_report_summary(
+                    metadata.document_id,
                     result["report"]["stack_info"],
                     json_output=json_output,
-                    title="Application stack guidance",
                 )
-
-            # Print report of the best one - thus index zero.
-            if result["report"] and result["report"]["products"]:
-                if result["report"]["products"][0]["justification"]:
-                    _print_report(
-                        result["report"]["products"][0]["justification"],
-                        json_output=json_output,
-                        title="Recommended stack report",
-                    )
+            elif diff:
+                if last_analysis_id:
+                    try:
+                        print_diff(metadata.document_id, last_analysis_id, json_output)
+                    except Exception:
+                        _LOGGER.warning(
+                            "An error occurred during the comparison process, so the advise will not be compared."
+                        )
                 else:
-                    click.echo("No justification was made for the recommended stack")
+                    _LOGGER.warning(
+                        "Could not retrieve last analysis id, so the advise will not be compared."
+                    )
+            elif json_output:
+                _print_report(
+                    result["report"],
+                    json_output=json_output,
+                )
+            else:
+                _print_advise_justifications(result, json_output=json_output)
+
+            if scoring:
+                scorecards_metrics = _compute_metrics_scorecards(result["report"])
+                if scorecards_metrics:
+                    Console().print(
+                        "Based on OSSF Security Scorecards ( https://github.com/ossf/scorecard ) :\n\n"
+                    )
+                    for message, metric in scorecards_metrics.items():
+                        Console().print(f"- {metric}% of {message}\n")
 
             pipfile = result["report"]["products"][0]["project"]["requirements"]
             pipfile_lock = result["report"]["products"][0]["project"][
@@ -868,9 +1093,11 @@ def provenance_check(
     Collect information about direct dependencies and dependencies stated in the lock file
     and send them to the remote service to verify their provenance.
 
-    Examples:
+    [bold yellow]Examples:[/bold yellow]
+    [purple]
 
-      thamos provenance-check --runtime-environment "production"
+      thamos provenance-check --runtime-environment production
+    [/purple]
     """
     with cwd(configuration.get_overlays_directory(runtime_environment)):
         if configuration.requirements_format != "pipenv":
@@ -909,6 +1136,44 @@ def provenance_check(
             sys.exit(4)
 
 
+@cli.command("diff")
+@click.pass_context
+@click.option(
+    "--json", "-j", "json_output", is_flag=True, help="Print output in JSON format."
+)
+@click.argument("new_analysis_id", type=str, required=True)
+@click.argument("old_analysis_id", type=str, required=False)
+@handle_cli_exception
+def print_diff(
+    new_analysis_id: str,
+    old_analysis_id: typing.Optional[str] = None,
+    json_output: bool = False,
+):
+    """Get the difference between two analyses' justification stacks.
+
+    If NEW_ANALYSIS_ID is not provided, the last request is used by default.
+    """
+    click.echo(f"Comparing old: {old_analysis_id} to new: {new_analysis_id}")
+
+    diff_lists = get_diff(new_analysis_id, old_analysis_id)
+
+    _print_report(
+        diff_lists["stack_info"],
+        json_output=json_output,
+        title="Stack Info Differences",
+    )
+    _print_report(
+        diff_lists["justifications"],
+        json_output=json_output,
+        title="Justification Differences",
+    )
+
+    if len(diff_lists["stack_info"]) == 0 and len(diff_lists["justifications"]) == 0:
+        click.echo(
+            "No differences found between the justifications and stack info of both documents."
+        )
+
+
 @cli.command("log")
 @click.pass_context
 @click.argument("analysis_id", type=str, required=False, metavar="ANALYSIS_ID")
@@ -966,11 +1231,13 @@ def status(
 
     If ANALYSIS_ID is not provided, the last request is used by default.
 
-    Examples:
+    [bold yellow]Examples:[/bold yellow]
+    [purple]
 
       thamos status
 
-      thamos status "adviser-940101080006-110c392feb7cf6da"
+      thamos status adviser-940101080006-110c392feb7cf6da
+    [/purple]
     """
     if not analysis_id:
         with cwd(configuration.get_overlays_directory(runtime_environment)):
@@ -1024,11 +1291,13 @@ def graph(
 
     If ANALYSIS_ID is not provided, the last request is used by default.
 
-    Examples:
+    [bold yellow]Examples:[/bold yellow]
+    [purple]
 
       thamos graph
 
-      thamos graph "adviser-940101080006-110c392feb7cf6da"
+      thamos graph adviser-940101080006-110c392feb7cf6da
+    [/purple]
     """
     with cwd(configuration.get_overlays_directory(runtime_environment)):
         printed = print_dependency_graph(analysis_id, fold=fold)
@@ -1036,15 +1305,55 @@ def graph(
             sys.exit(1)
 
 
+@cli.command("results")
+@click.pass_context
+@click.argument("analysis_id", type=str, required=False, metavar="ANALYSIS_ID")
+@click.option(
+    "--json", "-j", "json_output", is_flag=True, help="Print output in JSON format."
+)
+@click.option(
+    "--runtime-environment",
+    "-r",
+    default=None,
+    metavar="NAME",
+    envvar="THAMOS_RUNTIME_ENVIRONMENT",
+    help="Specify runtime environment used to retrieve analysis results.",
+)
+@handle_cli_exception
+def results(
+    analysis_id: typing.Optional[str] = None,
+    runtime_environment: typing.Optional[str] = None,
+    json_output: bool = False,
+) -> None:  # noqa: D412
+    """Show results of finished adviser analysis.
+
+    If ANALYSIS_ID is not provided, the last request is used by default.
+
+    [bold yellow]Examples:[/bold yellow]
+    [purple]
+
+      thamos results
+
+      thamos results adviser-940101080006-110c392feb7cf6da
+    [/purple]
+    """
+    with cwd(configuration.get_overlays_directory(runtime_environment)):
+        result = print_advise_results(analysis_id)
+
+        _print_advise_justifications(result, json_output=json_output)
+
+
 @cli.command("list")
 @click.pass_context
 @handle_cli_exception
 def list_() -> None:  # noqa: D412
     """List available runtime environments configured.
 
-    Examples:
+    [bold yellow]Examples:[/bold yellow]
+    [purple]
 
       thamos list
+    [/purple]
     """
     with workdir(configuration.CONFIG_NAME):
         environments = configuration.list_runtime_environments()
@@ -1082,9 +1391,11 @@ def show(
 ) -> None:  # noqa: D412
     """Show details for configured runtime environments.
 
-    Examples:
+    [bold yellow]Examples:[/bold yellow]
+    [purple]
 
-      thamos show --runtime-environment "development"
+      thamos show --runtime-environment development
+    [/purple]
     """
     with workdir(configuration.CONFIG_NAME):
         environments = configuration.list_runtime_environments()
@@ -1191,25 +1502,28 @@ def check(runtime_environment: Optional[str], output_format: str) -> None:  # no
     Check the correctness of the configuration file and runtime environment configuration
     for the current host.
 
-    Examples:
+    [bold yellow]Examples:[/bold yellow]
+    [purple]
 
-        thamos check --runtime-environment "production"
+        thamos check --runtime-environment production
 
         thamos check --output-format yaml
+    [/purple]
     """
     result = configuration.check(runtime_environment_name=runtime_environment)
 
-    if output_format == "yaml":
-        yaml.safe_dump(result, sys.stdout)
-    elif output_format == "json":
-        json.dump(result, sys.stdout, indent=2)
-        sys.stdout.write("\n")
-    elif output_format == "table":
-        _print_report(
-            result,
-            json_output=False,
-            title="Runtime environment and configuration check results",
-        )
+    if result:
+        if output_format == "yaml":
+            yaml.safe_dump(result, sys.stdout)
+        elif output_format == "json":
+            json.dump(result, sys.stdout, indent=2)
+            sys.stdout.write("\n")
+        elif output_format == "table":
+            _print_report(
+                result,
+                json_output=False,
+                title="Runtime environment and configuration check results",
+            )
 
     return_code = 1 if any(item.get("type") == "ERROR" for item in result) else 0
     if return_code == 0:
@@ -1308,13 +1622,15 @@ def images(
 ) -> None:  # noqa: D412
     """Check available Thoth container images.
 
-    Examples:
+    [bold yellow]Examples:[/bold yellow]
+    [purple]
 
       thamos images --output-format json
 
       thamos images --os-name fedora --os-version 35 --python-version 3.9
 
       thamos images --symbol GLIBC_FOO
+    [/purple]
     """
     result = list_thoth_container_images(
         os_name=os_name,
@@ -1336,14 +1652,35 @@ def images(
     elif output_format == "table":
         for item in result:
             table_content = []
+            container_image_search_link = ""
             for key, value in item.items():
+                if configuration.thoth_search_ui_url is not None:
+                    if key == "package_extract_document_id":
+                        container_image_search_link = (
+                            f"{configuration.thoth_search_ui_url}image/{value}"
+                        )
                 key = _REPORT_TRANSLATION_TABLE_IMAGES.get(
                     key, key.replace("_", " ").capitalize()
                 )
                 key = Text.from_markup(key, style="green bold")
                 # Here, key value are ignored. This is a trick to have "table header" as the first column.
+                if not value:
+                    continue
+
                 table_content.extend([{"key": key, "value": value}])
 
+            if container_image_search_link != "":
+                table_content.extend(
+                    [
+                        {
+                            "key": Text.from_markup(
+                                "See more details in Thoth Search UI:",
+                                style="bold cyan",
+                            ),
+                            "value": container_image_search_link,
+                        }
+                    ]
+                )
             _print_report(
                 table_content,
                 title=f"Container image {item.get('environment_name', 'UNKNOWN')}",
@@ -1427,15 +1764,17 @@ def add(
     Add one or multiple requirements to the direct dependency listing without actually installing them.
     The supplied requirement is specified using PEP-508 standard.
 
-    Examples:
+    [bold yellow]Examples:[/bold yellow]
+    [purple]
 
       thamos add flask
 
-      thamos add tensorflow --runtime-environment "training"
+      thamos add tensorflow --runtime-environment training
 
       thamos add --dev 'pytest~=6.2.0'
 
       thamos add 'importlib-metadata; python_version < "3.8"'
+    [/purple]
     """
     add_requirements_to_project(
         requirement=requirement,
@@ -1463,11 +1802,13 @@ def remove(
 ) -> None:  # noqa: D412
     """Remove the given requirement.
 
-    Examples:
+    [bold yellow]Examples:[/bold yellow]
+    [purple]
 
       thamos remove flask
 
-      thamos remove pytest --runtime-environment "training"
+      thamos remove pytest --runtime-environment training
+    [/purple]
     """
     project = configuration.get_project(runtime_environment)
 
@@ -1540,11 +1881,13 @@ def support(output: str) -> None:
 def whatprovides(import_name: str, output_format: str) -> None:  # noqa: D412
     """For a given import returns list of packages with matching modules.
 
-    Examples:
+    [bold yellow]Examples:[/bold yellow]
+    [purple]
 
       thamos whatprovides sklearn
 
-      thamos whatprovides sklearn.linear_model.*
+      thamos whatprovides 'sklearn.linear_model.*'
+    [/purple]
     """
     _LOGGER.info("Returning information on package %r", import_name)
 
@@ -1597,11 +1940,13 @@ def discover(
     If runtime environment is passed, requirements are added to requirements specific
     to the given runtime environment. Otherwise, the default runtime environment is used.
 
-    Examples:
+    [bold yellow]Examples:[/bold yellow]
+    [purple]
 
       thamos discover
 
-      thamos discover --runtime-environment "production"
+      thamos discover --runtime-environment production
+    [/purple]
     """
     # Obtain list of imports using invectio and verify package from PyPI
     verified_packages = get_verified_packages_from_static_analysis(
@@ -1635,9 +1980,11 @@ def discover(
 def environments_(output_format: str) -> None:  # noqa: D412
     """Show available Python environments.
 
-    Examples:
+    [bold yellow]Examples:[/bold yellow]
+    [purple]
 
       thamos environments
+    [/purple]
     """
     environments = list_python_environments()
 
@@ -1669,11 +2016,13 @@ def environments_(output_format: str) -> None:  # noqa: D412
 def verify(runtime_environment: typing.Optional[str]) -> None:  # noqa: D412
     """Verify the hash in Pipfile.lock is up-to-date in runtime environments configured.
 
-    Examples:
+    [bold yellow]Examples:[/bold yellow]
+    [purple]
 
         thamos verify
 
-        thamos verify --runtime-environment "training"
+        thamos verify --runtime-environment training
+    [/purple]
     """
     if configuration.requirements_format != "pipenv":
         _LOGGER.error(
