@@ -19,6 +19,7 @@
 
 import logging
 import os
+import re
 import sys
 from typing import Any
 from typing import Dict
@@ -45,6 +46,10 @@ from .discover import discover_distribution
 from .discover import discover_python_version
 from .discover import discover_platform
 from .discover import discover_base_image
+from .discover import discover_cudnn_version
+from .discover import discover_mkl_version
+from .discover import discover_rpm_package
+from .discover import discover_gpu_model
 from .exceptions import NoApiSupported
 from .exceptions import NoRuntimeEnvironmentError
 from .exceptions import RuntimeEnvironmentExistsError
@@ -157,6 +162,7 @@ class _Configuration:
         self.explicit_host = None
         self.tls_verify = None
         self._api_url = None
+        self._thoth_search_ui_url = None
 
     @property
     def api_url(self):
@@ -166,6 +172,13 @@ class _Configuration:
 
         return self._api_url
 
+    @property
+    def thoth_search_ui_url(self):
+        if not self._thoth_search_ui_url:
+            self.api_discovery(self.content["host"])
+
+        return self._thoth_search_ui_url
+
     @property
     def content(self):
         """Access configuration."""
@@ -224,8 +237,8 @@ class _Configuration:
             raise ConfigurationError("No virtual environment configured")
 
         virtualenv_args = [virtualenv_path]
-        re = self.get_runtime_environment(runtime_environment)
-        python_version = re.get("python_version")
+        runtime_environment_dict = self.get_runtime_environment(runtime_environment)
+        python_version = runtime_environment_dict.get("python_version")
         if python_version:
             virtualenv_args.extend(["--python", python_version])
 
@@ -310,16 +323,27 @@ class _Configuration:
         _LOGGER.info("Discovering host runtime environment")
 
         cpu_info = discover_cpu()
+        gpu_model = discover_gpu_model()
         cuda_version = discover_cuda_version()
         # Add quotes for textual representation in the config file.
-        cuda_version = f"'{cuda_version}'" if cuda_version is not None else "null"
+        cuda_version = f"'{cuda_version}'" or "null"
         os_name, os_version = discover_distribution()
         os_name = map_os_name(os_name)
         os_version = normalize_os_version(os_name, os_version)
         python_version = discover_python_version()
         platform = discover_platform()
         base_image = discover_base_image()
-        base_image = base_image if base_image is not None else "null"
+        base_image = base_image or "null"
+        cudnn_version = discover_cudnn_version()
+        cudnn_version = cudnn_version or "null"
+        mkl_version = discover_mkl_version()
+        mkl_version = mkl_version or "null"
+        openmpi_version = discover_rpm_package("openmpi")
+        openblas_version = discover_rpm_package("openblas")
+
+        runtime_environment_name = re.sub(
+            r"[^0-9a-zA-Z-]", "-", f"{os_name}-{os_version}"
+        )
 
         requirements_format = os.getenv(
             "THAMOS_REQUIREMENTS_FORMAT", self._DEFAULT_REQUIREMENTS_FORMAT
@@ -335,16 +359,22 @@ class _Configuration:
 
         expand_env = bool(int(os.getenv("THAMOS_CONFIG_EXPAND_ENV", 0)))
         default_config = default_config.format(
+            runtime_environment_name=runtime_environment_name,
             cuda_version=cuda_version,
+            cudnn_version=cudnn_version,
             os_name=os_name,
             os_version=os_version,
             python_version=python_version,
             platform=platform,
             requirements_format=requirements_format,
             base_image=base_image,
-            cpu_family=cpu_info["cpu_family"] or "null",
-            cpu_model=cpu_info["cpu_model"] or "null",
-            cpu_model_name=cpu_info["cpu_model_name"] or "CPU detection failed",
+            cpu_family=cpu_info.get("cpu_family", "null"),
+            cpu_model=cpu_info.get("cpu_model", "null"),
+            cpu_model_name=cpu_info.get("cpu_model_name", "CPU detection failed"),
+            gpu_model=gpu_model,
+            mkl_version=mkl_version,
+            openmpi_version=openmpi_version,
+            openblas_version=openblas_version,
             **(dict(os.environ) if expand_env else {}),
         )
 
@@ -481,6 +511,8 @@ class _Configuration:
             api_url, verify=self.tls_verify, headers={"Accept": "application/json"}
         )
 
+        self._thoth_search_ui_url = response.headers.get("X-Thoth-Search-Ui-Url")
+
         try:
             response.raise_for_status()
         except Exception as exc:
