@@ -32,6 +32,7 @@ from functools import partial
 from functools import wraps
 import pprint
 import json
+
 import urllib3
 import requests
 
@@ -84,7 +85,7 @@ _RECOMMENDATION_TYPES_URL = "https://thoth-station.ninja/recommendation-types/"
 _LOGGER = logging.getLogger(__name__)
 _RETRY_ON_ERROR_COUNT = int(os.getenv("THAMOS_RETRY_ON_ERROR_COUNT", 3))
 _RETRY_ON_ERROR_SLEEP = float(os.getenv("THAMOS_RETRY_ON_ERROR_SLEEP", 3.0))
-_THAMOS_TIMEOUT = int(os.getenv("THAMOS_TIMEOUT", 2000))
+_THAMOS_TIMEOUT = int(os.getenv("THAMOS_TIMEOUT", 2700))
 _THAMOS_TOKEN = os.getenv("THAMOS_TOKEN")
 _SOURCE = {
     "adviser": "advise/python",
@@ -378,8 +379,6 @@ def advise_using_config(
     no_user_stack: bool = False,
     nowait: bool = False,
     force: bool = False,
-    limit: typing.Optional[int] = None,
-    count: int = 1,
     debug: bool = False,
     origin: typing.Optional[str] = None,
     timeout: typing.Optional[int] = None,
@@ -411,8 +410,6 @@ def advise_using_config(
         no_user_stack=no_user_stack,
         nowait=nowait,
         force=force,
-        limit=limit,
-        count=count,
         debug=debug,
         origin=origin,
         timeout=timeout,
@@ -442,8 +439,6 @@ def advise(
     no_user_stack: bool = False,
     nowait: bool = False,
     force: bool = False,
-    limit: typing.Optional[int] = None,
-    count: int = 1,
     debug: bool = False,
     origin: typing.Optional[str] = None,
     timeout: typing.Optional[int] = None,
@@ -548,12 +543,6 @@ def advise(
         "dev": dev,
     }  # type: Dict[str, Any]
 
-    if limit is not None:
-        parameters["limit"] = limit
-
-    if count is not None:
-        parameters["count"] = count
-
     if origin is not None:
         parameters["origin"] = origin
 
@@ -599,7 +588,7 @@ def advise(
         return None
 
     _LOGGER.debug("Adviser check metadata: %r", response.metadata)
-    return response.result.to_dict(), response.result.error
+    return response.result.to_dict(), response.result.error, response.metadata
 
 
 def advise_here(
@@ -613,8 +602,6 @@ def advise_here(
     no_user_stack: bool = False,
     nowait: bool = False,
     force: bool = False,
-    limit: typing.Optional[int] = None,
-    count: int = 1,
     debug: bool = False,
     timeout: typing.Optional[int] = None,
     origin: typing.Optional[str] = None,
@@ -717,8 +704,6 @@ def advise_here(
             no_user_stack=no_user_stack,
             nowait=nowait,
             force=force,
-            limit=limit,
-            count=count,
             debug=debug,
             origin=origin,
             timeout=timeout,
@@ -1024,6 +1009,118 @@ def get_log(api_client: ApiClient, analysis_id: str = None):
     return result
 
 
+@with_api_client
+def get_diff(api_client: ApiClient, new_analysis_id: str, old_analysis_id: str = None):
+    """Get the difference of two analyses justification stack - the analysis type must be of type 'adviser-'.
+
+    If old_analysis_id is not provided, its get from the last thamos call which stores it in a temporary file.
+    """
+    api_instance = AdviseApi(api_client)
+
+    # get last used analysis ID if old not provided; raise exception if no last id
+    if not old_analysis_id:
+        old_analysis_id = get_last_analysis_id()
+
+    # get old advise document; raise exception if id is invalid
+    if old_analysis_id.startswith("adviser-"):
+        old_result = api_instance.get_advise_python(old_analysis_id)  # type: ignore
+    else:
+        raise UnknownAnalysisType(
+            "Can only compare the differences between 'adviser-' type ids."
+        )
+
+    # validate adviser id and get new document
+    if new_analysis_id:
+        if new_analysis_id.startswith("adviser-"):
+            new_result = api_instance.get_advise_python(new_analysis_id)  # type: ignore
+        else:
+            raise UnknownAnalysisType(
+                "Can only compare the differences between 'adviser-' type ids."
+            )
+    else:
+        raise ValueError("Missing a new analysis ID to compare to.")
+
+    # get stack info and justification from response
+    old_justifications = []
+    new_justifications = []
+    old_stack = []
+    new_stack = []
+
+    try:
+        old_justifications = old_result.result.report.products[0].justification
+    except (TypeError, KeyError):
+        _LOGGER.warning("Could not get justifications from old advise document.")
+
+    try:
+        new_justifications = new_result.result.report.products[0].justification
+    except (TypeError, KeyError):
+        _LOGGER.warning("Could not get justifications from new advise document.")
+
+    try:
+        old_stack = old_result.result.report.stack_info
+    except (TypeError, KeyError):
+        _LOGGER.warning("Could not get stack info from old advise document.")
+
+    try:
+        new_stack = new_result.result.report.stack_info
+    except (TypeError, KeyError):
+        _LOGGER.warning("Could not get stack info from new advise document.")
+
+    # helper function that compares justification types
+    def compare_justification_list(old, new):
+        # helper function that hashes a single justification
+        def _hash_justification(justification):
+            return hash(
+                str(justification.get("link"))
+                + str(justification.get("type"))
+                + str(justification.get("message"))
+                + str(justification.get("package_name"))
+            )
+
+        compare_dict = {}
+        for justification in old:
+            hashed_justification = _hash_justification(justification)
+            compare_dict[hashed_justification] = {
+                "value": justification,
+                "old": True,
+                "new": False,
+            }
+
+        for justification in new:
+            hashed_justification = _hash_justification(justification)
+            if hashed_justification in compare_dict:
+                compare_dict[hashed_justification]["new"] = True
+            else:
+                compare_dict[hashed_justification] = {
+                    "value": justification,
+                    "old": False,
+                    "new": True,
+                }
+
+        # recreated list with difference param and discard equal justifications
+        reconstructed_list = []
+        for key in compare_dict:
+            if compare_dict[key]["new"] and compare_dict[key]["old"]:
+                continue
+            elif compare_dict[key]["new"]:
+                difference = "ADDED"
+            else:
+                difference = "REMOVED"
+
+            reconstructed_list.append(
+                {**compare_dict[key]["value"], "difference": difference}
+            )
+
+        return reconstructed_list
+
+    return {
+        "stack_info": compare_justification_list(old_stack, new_stack),
+        "justifications": compare_justification_list(
+            old_justifications, new_justifications
+        ),
+    }
+
+
 @with_api_client
 def get_status(api_client: ApiClient, analysis_id: typing.Optional[str] = None):
     """Get status of an analysis - the analysis type and endpoint are automatically derived from analysis id.
@@ -1512,7 +1609,7 @@ def collect_support_information_dict() -> Dict[str, Any]:
         "platform_system": platform.system(),
         "platform_version": platform.version(),
         "python_full_version": platform.python_version(),
-        "python_version": platform.python_version()[:3],
+        "python_version": ".".join(platform.python_version().split(".")[:2]),
         "sys_platform": sys.platform,
         "pip_freeze": pip_freeze,
         "discovery": discovery,
@@ -1601,9 +1698,17 @@ def print_dependency_graph_from_adviser_document(
     pipfile_lock = adviser_document["report"]["products"][0]["project"][
         "requirements_locked"
     ]
-    for direct_dependency in chain(
-        pipfile["packages"].keys(), pipfile["dev-packages"].keys()
-    ):
+
+    direct_dependencies = pipfile["packages"].keys()
+    if adviser_document["parameters"]["dev"]:
+        # Include dev packages in the listing only if dev flag was supplied
+        direct_dependencies = chain(direct_dependencies, pipfile["dev-packages"].keys())
+    else:
+        _LOGGER.warning(
+            "Development dependencies will not be shown as no --dev flag was supplied to the resolution process"
+        )
+
+    for direct_dependency in direct_dependencies:
         direct_dependency_idx = nodes_idx[direct_dependency]
         print(f"→ {_get_package_entry_str(pipfile_lock, direct_dependency)}")
         _traverse_edges(
@@ -1637,6 +1742,25 @@ def print_dependency_graph(
     return print_dependency_graph_from_adviser_document(adviser_document, fold=fold)
 
 
+def print_advise_results(analysis_id: typing.Optional[str] = None):
+    """Print dependency graph to stdout produced by the given adviser."""
+    analysis_id = analysis_id or get_last_analysis_id()
+    if not analysis_id.startswith("adviser-"):
+        raise UnknownAnalysisType(
+            f"An adviser identifier is required to print a analysis results, got {analysis_id!r} instead"
+        )
+
+    adviser_document, error = get_analysis_results(analysis_id)
+
+    if error:
+        print("Cannot print analysis results as advise was not successful")
+
+    if not adviser_document:
+        sys.exit(2)
+
+    return adviser_document
+
+
 def add_requirements_to_project(
     requirement: typing.List[str],
     runtime_environment: typing.Optional[str],
